@@ -49,8 +49,8 @@ class DeployUtils:
     @staticmethod
     def run_common_stuff(env, tier, pemfile):#${env_str} $host $password $username $database $lb_name ${pemfile} ${a}):
         logging.info("Running common stuff recipe on all nodes because -c argument is specified.")
-        runlist = '{"run_list":["recipe[webslave::common_stuff]"]}'
-        chef_command = "echo '%s' > /tmp/runlist; sudo chef-client -j /tmp/runlist -E %s" % (runlist, env)
+        run_list = '{"run_list":["recipe[webslave::common_stuff]"]}'
+        chef_command = "echo '%s' > /tmp/runlist; sudo chef-client -j /tmp/runlist -E %s" % (run_list, env)
         retcode = DeployUtils.run_chef_command(chef_command, env, tier, pemfile, "")
         logging.info("-------Done with running the common stuff recipe--------")
         return retcode
@@ -60,8 +60,8 @@ class DeployUtils:
                                     env):#${env_str} $host $password $username $database $lb_name ${pemfile} ${a}):
         chef_command = "sudo chef-client -j /etc/chef/first-boot.json -E %s" % (env)
         if module != "all":
-            runlist = '{"run_list":["recipe[webslave::deploy_%s]"]}' % (module)
-            chef_command = "echo '%s' > /tmp/runlist; sudo chef-client -j /tmp/runlist" % (runlist)
+            run_list = '{"run_list":["recipe[webslave::deploy_%s]"]}' % (module)
+            chef_command = "echo '%s' > /tmp/runlist; sudo chef-client -j /tmp/runlist" % (run_list)
         return chef_command
 
     @staticmethod
